# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import ActionRequestArchivedClass
from .....schema_classes import ActionRequestEvalAssignmentClass
from .....schema_classes import ActionRequestEvalsClass
from .....schema_classes import ActionRequestInfoClass
from .....schema_classes import ActionRequestOriginClass
from .....schema_classes import ActionRequestParamsClass
from .....schema_classes import ActionRequestStatusClass
from .....schema_classes import CreateGlossaryNodeProposalClass
from .....schema_classes import CreateGlossaryTermProposalClass
from .....schema_classes import DataContractProposalClass
from .....schema_classes import DataContractProposalOperationTypeClass
from .....schema_classes import DescriptionProposalClass
from .....schema_classes import DocumentChangeClass
from .....schema_classes import DocumentProposalTypeClass
from .....schema_classes import DocumentsProposalClass
from .....schema_classes import DomainProposalClass
from .....schema_classes import GlossaryTermProposalClass
from .....schema_classes import LifecycleStageProposalClass
from .....schema_classes import OwnerProposalClass
from .....schema_classes import StructuredPropertyProposalClass
from .....schema_classes import TagProposalClass
from .....schema_classes import TaskInputOptionClass
from .....schema_classes import TaskInputParamsClass


ActionRequestArchived = ActionRequestArchivedClass
ActionRequestEvalAssignment = ActionRequestEvalAssignmentClass
ActionRequestEvals = ActionRequestEvalsClass
ActionRequestInfo = ActionRequestInfoClass
ActionRequestOrigin = ActionRequestOriginClass
ActionRequestParams = ActionRequestParamsClass
ActionRequestStatus = ActionRequestStatusClass
CreateGlossaryNodeProposal = CreateGlossaryNodeProposalClass
CreateGlossaryTermProposal = CreateGlossaryTermProposalClass
DataContractProposal = DataContractProposalClass
DataContractProposalOperationType = DataContractProposalOperationTypeClass
DescriptionProposal = DescriptionProposalClass
DocumentChange = DocumentChangeClass
DocumentProposalType = DocumentProposalTypeClass
DocumentsProposal = DocumentsProposalClass
DomainProposal = DomainProposalClass
GlossaryTermProposal = GlossaryTermProposalClass
LifecycleStageProposal = LifecycleStageProposalClass
OwnerProposal = OwnerProposalClass
StructuredPropertyProposal = StructuredPropertyProposalClass
TagProposal = TagProposalClass
TaskInputOption = TaskInputOptionClass
TaskInputParams = TaskInputParamsClass

# fmt: on
